# Changelog

## [0.0.12a30](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.12a30) (2023-06-16)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a29...0.0.12a30)

**Merged pull requests:**

- updated requirements [\#99](https://github.com/OpenVoiceOS/OVOS-workshop/pull/99) ([builderjer](https://github.com/builderjer))

## [V0.0.12a29](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a29) (2023-06-15)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a28...V0.0.12a29)

**Merged pull requests:**

- Update AudioInterface reference to resolve deprecation warning [\#98](https://github.com/OpenVoiceOS/OVOS-workshop/pull/98) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a28](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a28) (2023-06-14)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a27...V0.0.12a28)

**Fixed bugs:**

- fix skill initialization compat + unittests [\#95](https://github.com/OpenVoiceOS/OVOS-workshop/pull/95) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a27](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a27) (2023-05-17)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a26...V0.0.12a27)

**Merged pull requests:**

- Refactor to remove deprecated reference [\#90](https://github.com/OpenVoiceOS/OVOS-workshop/pull/90) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a26](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a26) (2023-05-17)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a25...V0.0.12a26)

**Implemented enhancements:**

- Implement Unit Tests [\#89](https://github.com/OpenVoiceOS/OVOS-workshop/pull/89) ([NeonDaniel](https://github.com/NeonDaniel))

**Closed issues:**

- When core restart, the skill returns an error [\#82](https://github.com/OpenVoiceOS/OVOS-workshop/issues/82)

## [V0.0.12a25](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a25) (2023-05-03)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a24...V0.0.12a25)

**Fixed bugs:**

- fix/core\_reload in standalone launcher [\#88](https://github.com/OpenVoiceOS/OVOS-workshop/pull/88) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a24](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a24) (2023-05-01)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a23...V0.0.12a24)

**Implemented enhancements:**

- refactor/skill\_init\_wizardry [\#70](https://github.com/OpenVoiceOS/OVOS-workshop/pull/70) ([JarbasAl](https://github.com/JarbasAl))

**Merged pull requests:**

- fix/codecov automation [\#87](https://github.com/OpenVoiceOS/OVOS-workshop/pull/87) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a23](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a23) (2023-04-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a22...V0.0.12a23)

**Fixed bugs:**

- fix/missing\_requirement [\#86](https://github.com/OpenVoiceOS/OVOS-workshop/pull/86) ([JarbasAl](https://github.com/JarbasAl))

**Merged pull requests:**

- workflow/codecov [\#85](https://github.com/OpenVoiceOS/OVOS-workshop/pull/85) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a22](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a22) (2023-04-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a21...V0.0.12a22)

**Fixed bugs:**

- fix/activate\_plugin\_skills [\#84](https://github.com/OpenVoiceOS/OVOS-workshop/pull/84) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a21](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a21) (2023-04-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a20...V0.0.12a21)

**Fixed bugs:**

- fix/super\_fallbacks [\#83](https://github.com/OpenVoiceOS/OVOS-workshop/pull/83) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a20](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a20) (2023-04-26)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a19...V0.0.12a20)

**Fixed bugs:**

- fix/fallback\_some\_more [\#81](https://github.com/OpenVoiceOS/OVOS-workshop/pull/81) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a19](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a19) (2023-04-26)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a18...V0.0.12a19)

**Fixed bugs:**

- fix/fallback [\#80](https://github.com/OpenVoiceOS/OVOS-workshop/pull/80) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a18](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a18) (2023-04-25)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a17...V0.0.12a18)

**Implemented enhancements:**

- refactor/fallback\_skills\_v2 [\#66](https://github.com/OpenVoiceOS/OVOS-workshop/pull/66) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a17](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a17) (2023-04-24)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a16...V0.0.12a17)

## [V0.0.12a16](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a16) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a15...V0.0.12a16)

**Implemented enhancements:**

- feat/standalone\_skills [\#78](https://github.com/OpenVoiceOS/OVOS-workshop/pull/78) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a15](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a15) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a14...V0.0.12a15)

**Merged pull requests:**

- python-version: \[ 3.7, 3.8, 3.9, "3.10", "3.11"\] [\#77](https://github.com/OpenVoiceOS/OVOS-workshop/pull/77) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a14](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a14) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a13...V0.0.12a14)

**Merged pull requests:**

- refactor/common\_qa\_speak [\#63](https://github.com/OpenVoiceOS/OVOS-workshop/pull/63) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a13](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a13) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a12...V0.0.12a13)

**Fixed bugs:**

- fix/is\_classic\_core2 [\#76](https://github.com/OpenVoiceOS/OVOS-workshop/pull/76) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a12](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a12) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a11...V0.0.12a12)

**Fixed bugs:**

- fix/classic core checks [\#75](https://github.com/OpenVoiceOS/OVOS-workshop/pull/75) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a11](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a11) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a10...V0.0.12a11)

**Implemented enhancements:**

- feat/auto\_tx\_skills\_continued [\#74](https://github.com/OpenVoiceOS/OVOS-workshop/pull/74) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a10](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a10) (2023-04-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a9...V0.0.12a10)

**Fixed bugs:**

- ERROR - No module named 'ovos\_utils.lang.translate' [\#67](https://github.com/OpenVoiceOS/OVOS-workshop/issues/67)
- fix/universal\_skills\_are\_back [\#72](https://github.com/OpenVoiceOS/OVOS-workshop/pull/72) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a9](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a9) (2023-04-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a8...V0.0.12a9)

**Fixed bugs:**

- fix/skill\_launcher\_locale\_init [\#71](https://github.com/OpenVoiceOS/OVOS-workshop/pull/71) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a8](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a8) (2023-04-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a7...V0.0.12a8)

**Merged pull requests:**

- refactor/move\_intent\_decorators [\#73](https://github.com/OpenVoiceOS/OVOS-workshop/pull/73) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a7](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a7) (2023-04-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a6...V0.0.12a7)

**Implemented enhancements:**

- feat/skill\_launcher [\#65](https://github.com/OpenVoiceOS/OVOS-workshop/pull/65) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a6) (2023-04-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a5...V0.0.12a6)

**Merged pull requests:**

- Cleanup Changes [\#64](https://github.com/OpenVoiceOS/OVOS-workshop/pull/64) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a5) (2023-04-18)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a4...V0.0.12a5)

**Merged pull requests:**

- Update automation to match ovos-utils [\#62](https://github.com/OpenVoiceOS/OVOS-workshop/pull/62) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a4) (2023-04-14)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a3...V0.0.12a4)

**Implemented enhancements:**

- feat/common\_qa\_class [\#61](https://github.com/OpenVoiceOS/OVOS-workshop/pull/61) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a3) (2023-04-05)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a2...V0.0.12a3)

**Merged pull requests:**

- ovos-bus-client + skillGui class in ovos\_workshop [\#57](https://github.com/OpenVoiceOS/OVOS-workshop/pull/57) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a2) (2023-03-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a1...V0.0.12a2)

**Closed issues:**

- Add helper function `voc_list` to the OvosSkill class [\#53](https://github.com/OpenVoiceOS/OVOS-workshop/issues/53)

**Merged pull requests:**

- Add backwards-compat. voc\_cache property and setter [\#55](https://github.com/OpenVoiceOS/OVOS-workshop/pull/55) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a1) (2023-03-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.11...V0.0.12a1)

**Merged pull requests:**

- add `voc_list` helper function [\#54](https://github.com/OpenVoiceOS/OVOS-workshop/pull/54) ([emphasize](https://github.com/emphasize))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
